@@ -12,6 +12,10 @@ ulimit -c unlimited
 if test "$USE_VALGRIND" = ""; then
 	./cluster_mgr ${cnfpath} >../log/std.log 2>&1
 else
-	valgrind --leak-check=full --trace-children=yes --undef-value-errors=no ./cluster_mgr ${cnfpath} >../log/std.log 2>&1
+	valgrind --leak-check=full --undef-value-errors=no ./cluster_mgr ${cnfpath} >../log/std.log 2>&1
 fi
+
+# sleep 5 seconds to let the process appear in ps command, for busy machines.
+sleep 5
+
 ps -ef | grep ${cnfpath} | grep -v grep
